package models

import (
	"fmt"
	"time"
)

type Device struct {
	TOPIC       string
	CustomerID  string
	DeviceID    string
	ProjectName string
	MAC         string
	SN          string
	LastMsg     string
}

func (db *DB) AllDevices() ([]*Device, error) {
	rows, err := db.Query("SELECT * FROM devices")
	if err != nil {
		return nil, err
	}
	defer rows.Close()

	devices := make([]*Device, 0)
	for rows.Next() {
		device := new(Device)
		err := rows.Scan(&device.TOPIC, &device.CustomerID, &device.DeviceID, &device.ProjectName, &device.MAC, &device.SN, &device.LastMsg)
		if err != nil {
			return nil, err
		}
		device.ProjectName, err = db.GetProjectName(device.CustomerID)
		devices = append(devices, device)
	}
	if err = rows.Err(); err != nil {
		return nil, err
	}

	return devices, nil
}

func (db *DB) InsertDevice(device *Device) error {

	timeStamp := time.Now().Format(time.RFC3339)
	// DEBUG
	fmt.Printf("Timestamp: %s\n", timeStamp)

	sqlStmt := `INSERT OR REPLACE INTO devices (topic, customerID, deviceID, projectName, mac, sn)
                VALUES($1, $2, $3, $4, $5, $6);`
	_, err := db.Exec(sqlStmt, device.TOPIC, device.CustomerID, device.DeviceID, device.ProjectName, device.MAC, device.SN)
	if err != nil {
		return err
	}

	// DEBUG
	fmt.Printf("Sucessfully inserted device with ID %s to database\n", device.TOPIC)

	return err
}

func (db *DB) GetProjectName(projectNumber string) (string, error) {

	projectNameRows, err := db.Query("SELECT projectName FROM projects WHERE projectNumber =  $1", projectNumber)
	if err != nil {
		return "", err
	}
	defer projectNameRows.Close()

	projectName := ""
	for projectNameRows.Next() {
		err := projectNameRows.Scan(&projectName)
		if err != nil {
			return "", err
		}
	}
	if err = projectNameRows.Err(); err != nil {
		return "", err
	}

	return projectName, err

}
